#!/bin/bash

if [ $SUDO_USER ];
	then USER=$SUDO_USER;
	else USER=`/usr/bin/whoami`;
fi

appDirectory=/home/$USER/.config/Solar\ dVPN/;
if [ -d "$appDirectory" ]; then
    /usr/bin/echo 'Removing the configs'
    /usr/bin/rm -rf "$appDirectory";
fi

solardvpncliDirectory=/home/$USER/.solardvpn-cli/;
if [ -d "$solardvpncliDirectory" ]; then
    /usr/bin/echo 'Removing the solardvpncli configs'
    /usr/bin/rm -rf "$solardvpncliDirectory";
fi

dvpnDaemonFile=/etc/systemd/system/solardvpn-cli.service
if [ -f "$dvpnDaemonFile" ]; then
  /usr/bin/echo 'Removing the solardvpncli daemon'
  /usr/bin/systemctl stop solardvpn-cli.service
  /usr/bin/systemctl disable solardvpn-cli.service
  /usr/bin/rm "$dvpnDaemonFile"
  # /usr/bin/rm /etc/systemd/system/multi-user.target.wants/solardvpn-cli.service
  /usr/bin/systemctl daemon-reload
  /usr/bin/systemctl reset-failed
fi

solarStealthDaemonFile=/etc/systemd/system/solarstealth-proxy-controller.service
if [ -f "$solarStealthDaemonFile" ]; then
  /usr/bin/echo 'Removing the solarstealth-proxy-controller daemon'
  /usr/bin/systemctl stop solarstealth-proxy-controller.service
  /usr/bin/systemctl disable solarstealth-proxy-controller.service
  /usr/bin/rm "$solarStealthDaemonFile"
  # /usr/bin/rm /etc/systemd/system/multi-user.target.wants/solarstealth-proxy-controller.service
  /usr/bin/systemctl daemon-reload
  /usr/bin/systemctl reset-failed
fi

keyringPid=$(/usr/bin/pgrep -f "solardvpn-cli.+\--with-keyring") || keyringPid=0
if [ $keyringPid -gt 0 ]; then
  /usr/bin/echo 'Killing a solardvpncli keyring process'
  /usr/bin/kill $keyringPid
fi

/usr/bin/echo 'Copying solardvpncli'
/usr/bin/cp /opt/Solar\ dVPN/bin/solardvpn-cli /usr/local/bin/solardvpn-cli

/usr/bin/echo 'Copying SolarStealthProxyController'
/usr/bin/cp /opt/Solar\ dVPN/bin/SolarStealthProxyController /usr/local/sbin/SolarStealthProxyController

/usr/bin/echo 'Copying solarstealth-tun2socks'
/usr/bin/cp /opt/Solar\ dVPN/bin/solarstealth-tun2socks /usr/local/bin/solarstealth-tun2socks

/usr/bin/echo 'Create stealthvpn group'
/usr/sbin/groupadd -f "stealthvpn"
if /usr/bin/id "$USER" &>/dev/null; then
  /usr/sbin/usermod -aG "stealthvpn" "$USER"
  /usr/bin/echo "user $USER has been added to stealthvpn group"
else
  /usr/bin/echo "warn: no user will be added to stealthvpn group"
fi

/usr/bin/echo 'Copying the daemons'
/usr/bin/cp /opt/Solar\ dVPN/services/solardvpn-cli.service /etc/systemd/system
/usr/bin/cp /opt/Solar\ dVPN/services/solarstealth-proxy-controller.service /etc/systemd/system

if /usr/bin/id "$USER" &>/dev/null; then
  uid="$(/usr/bin/id -u "$USER")"
  /usr/bin/sed -i "s/--owning-user-id=-1/--owning-user-id=$uid/g" "/etc/systemd/system/solarstealth-proxy-controller.service"
fi

/usr/bin/echo 'Start the daemons'
/usr/bin/systemctl daemon-reload
/usr/bin/systemctl enable solardvpn-cli.service
/usr/bin/systemctl start solardvpn-cli.service
/usr/bin/systemctl enable solarstealth-proxy-controller.service
/usr/bin/systemctl start solarstealth-proxy-controller.service

/usr/bin/sleep 2